@@ -355,7 +355,8 @@ typedef enum
 	GGIT_CONFIG_LEVEL_XDG         = 3,
 	GGIT_CONFIG_LEVEL_GLOBAL      = 4,
 	GGIT_CONFIG_LEVEL_LOCAL       = 5,
-	GGIT_CONFIG_LEVEL_APP         = 6,
+	GGIT_CONFIG_LEVEL_WORKTREE    = 6,
+	GGIT_CONFIG_LEVEL_APP         = 7,
 	GGIT_CONFIG_LEVEL_HIGHEST     = -1
 } GgitConfigLevel;
 
@@ -393,7 +394,11 @@ typedef enum {
 	GGIT_DELTA_RENAMED    = 4,
 	GGIT_DELTA_COPIED     = 5,
 	GGIT_DELTA_IGNORED    = 6,
-	GGIT_DELTA_UNTRACKED  = 7
+	GGIT_DELTA_UNTRACKED  = 7,
+	GGIT_DELTA_TYPECHANGE = 8,
+	GGIT_DELTA_UNREADABLE = 9,
+	GGIT_DELTA_CONFLICTED = 10,
+
 } GgitDeltaType;
 
 /**
@@ -624,6 +629,20 @@ typedef enum {
 	GGIT_MERGE_NO_RECURSIVE     = (1 << 3)
 } GgitMergeFlags;
 
+/**
+ * GgitProxyType:
+ * @GGIT_PROXY_NONE: Do not attempt to connect through a proxy.
+ * @GGIT_PROXY_AUTO: Try to auto-detect the proxy from the git configuration.
+ * @GGIT_PROXY_SPECIFIED: Connect via the URL given in the options.
+ *
+ * The type of proxy to use.
+ */
+typedef enum {
+	GGIT_PROXY_NONE,
+	GGIT_PROXY_AUTO,
+	GGIT_PROXY_SPECIFIED
+} GgitProxyType;
+
 /**
  * GgitRebaseOperationType:
  * @GGIT_REBASE_OPERATION_PICK: The given commit is to be cherry-picked.
@@ -786,7 +805,10 @@ typedef enum {
 	GGIT_STATUS_WORKING_TREE_MODIFIED   = 1 << 8,
 	GGIT_STATUS_WORKING_TREE_DELETED    = 1 << 9,
 	GGIT_STATUS_WORKING_TREE_TYPECHANGE = 1 << 10,
-	GGIT_STATUS_IGNORED                 = 1 << 14
+	GGIT_STATUS_WORKING_TREE_RENAMED    = 1 << 11,
+	GGIT_STATUS_WORKING_TREE_UNREADABLE = 1 << 12,
+	GGIT_STATUS_IGNORED                 = 1 << 14,
+	GGIT_STATUS_CONFLICTED              = 1 << 15,
 } GgitStatusFlags;
 
 /**
@@ -1126,7 +1148,7 @@ typedef gint (* GgitDiffHunkCallback) (GgitDiffDelta *delta,
 /**
  * GgitDiffLineCallback:
  * @delta: a #GgitDiffDelta.
- * @hunk: a #GgitDiffHunk.
+ * @hunk: (nullable): a #GgitDiffHunk.
  * @line: a #GgitDiffLine.
  * @user_data: (closure): user-supplied data.
  *
